@@ -1,23 +1,23 @@
 package Acme::Mitey::Cards::Card::Face;
 
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 our $AUTHORITY = 'cpan:TOBYINK';
 
-use Acme::Mitey::Cards::Mite;
+use Acme::Mitey::Cards::Mite qw( -bool -is );
 extends 'Acme::Mitey::Cards::Card';
 
 use Acme::Mitey::Cards::Suit;
 
 has suit => (
-	is => 'ro',
-	isa => 'InstanceOf["Acme::Mitey::Cards::Suit"]',
-	required => 1,
+	is       => ro,
+	isa      => 'InstanceOf["Acme::Mitey::Cards::Suit"]',
+	required => true,
 );
 
 has face => (
-	is => 'ro',
-	isa => 'Enum[ "Jack", "Queen", "King" ]',
-	required => 1,
+	is       => ro,
+	isa      => 'Enum[ "Jack", "Queen", "King" ]',
+	required => true,
 );
 
 sub face_abbreviation {
