@@ -1,9 +1,9 @@
 package Acme::Mitey::Cards::Card::Joker;
 
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 our $AUTHORITY = 'cpan:TOBYINK';
 
-use Acme::Mitey::Cards::Mite;
+use Acme::Mitey::Cards::Mite qw( -bool -is );
 extends 'Acme::Mitey::Cards::Card';
 
 sub to_string {
